import requests
import xmltodict
import json
from datetime import datetime, timedelta

from . import utils


class FasAd:

    def __init__(self, company_id, office_id):
        self.company_id = company_id
        self.office_id = office_id

    def _get_json_from_url(self, url, key=None):
        xml = self._get_xml_from_url(url)
        try:
            result = xmltodict.parse(xml)
            if key:
                return utils.ensure_list(result[key]['Item'])
            else:
                return result['Item']
        except TypeError:
            return []

    def _get_xml_from_url(self, url, encoding='utf-8'):
        response = requests.get(url)

        response.raise_for_status()

        response.encoding = encoding
        xml = response.text

        return xml

    def _save_xml_and_json(self, url):
        xml = self._get_xml_from_url(url)
        js = self._get_json_from_url(url, 'Objects')

        with open('fasad/test_data/real_estates/normal.xml', mode='w', encoding='utf-8') as f:
            f.write(xml)

        with open('fasad/test_data/real_estates/normal.json', mode='w', encoding='utf-8') as f:
            f.write(json.dumps(js))

    def save_real_estate(self, fasad_id):
        url = 'http://beskrivning.fasad.eu/objekt/{fasad_id}/beskrivning.xml'.format(
            fasad_id=fasad_id)

        xml = self._get_xml_from_url(url)
        js = self.real_estate(fasad_id)

        with open('fasad/test_data/real_estate/{}.xml'.format(fasad_id),
                  mode='w', encoding='utf-8') as f:
            f.write(xml)

        with open('fasad/test_data/real_estate/{}.json'.format(fasad_id),
                  mode='w', encoding='utf-8') as f:
            f.write(json.dumps(js))

    def save_realtors(self):
        url = 'http://beskrivning.fasad.eu/bolag/{company_id}/butik-{office_id}.xml'.format(
            company_id=self.company_id,
            office_id=self.office_id)

        xml = self._get_xml_from_url(url)
        js = self.realtors()

        with open('fasad/test_data/realtors/normal.xml', mode='w', encoding='utf-8') as f:
            f.write(xml)

        with open('fasad/test_data/realtors/normal.json', mode='w', encoding='utf-8') as f:
            f.write(json.dumps(js))

    def realtors(self):
        """
        Return a list with a JSON representation of all realtors.
        """
        url = 'http://beskrivning.fasad.eu/bolag/{company_id}/butik-{office_id}.xml'.format(
            company_id=self.company_id,
            office_id=self.office_id)

        return self._get_json_from_url(url=url, key='Realtors')

    def real_estates(self):
        """
        Return a list with a shortened JSON representation of all real estates.
        """
        url = 'http://beskrivning.fasad.eu/bolag/{company_id}/objekt.xml'.format(
            company_id=self.company_id)

        real_estates = self._get_json_from_url(url=url, key='Objects')

        return real_estates

    def real_estate(self, fasad_id):
        """
        Return a complete JSON representation of the requested real estate.
        """
        url = 'http://beskrivning.fasad.eu/objekt/{fasad_id}/beskrivning.xml'.format(
            fasad_id=fasad_id)

        return self._get_json_from_url(url)
