import faker
import factory
from factory import lazy_attribute

from django.utils import timezone

from . import models

fake = faker.Factory.create('sv_SE')


class Realtor(factory.DjangoModelFactory):

    class Meta:
        model = models.Realtor

    fasad_id = fake.random_number()
    priority = factory.Sequence(lambda n: n)


class RealEstate(factory.DjangoModelFactory):

    class Meta:
        model = models.RealEstate

    fasad_id = factory.Sequence(lambda n: n)
    published_date = timezone.make_aware(fake.date_time())
    modified_date = timezone.make_aware(fake.date_time())
    address = factory.Sequence(lambda n: 'address{}'.format(n))

    realtor = factory.SubFactory(Realtor)


class Showing(factory.DjangoModelFactory):

    class Meta:
        model = models.Showing

    start_date = timezone.make_aware(fake.date_time())
    end_date = timezone.make_aware(fake.date_time())
    comment = fake.text(max_nb_chars=20)
    real_estate = factory.SubFactory(RealEstate)


class Bid(factory.DjangoModelFactory):

    class Meta:
        model = models.Bid

    amount = fake.random_int()
    bidder = factory.Sequence(lambda n: 'Budgivare {}'.format(n))
    real_estate = factory.SubFactory(RealEstate)


class Image(factory.DjangoModelFactory):

    class Meta:
        model = models.Image

    fasad_id = fake.random_int()
    width = fake.random_int()
    height = fake.random_int()
    file_size = fake.random_int()
    priority = factory.Sequence(lambda n: n)
    real_estate = factory.SubFactory(RealEstate)
