from django.core.management.base import BaseCommand

from fasad.models import Realtor, RealEstate


class Command(BaseCommand):
    help = 'Fetches fresh information from FasAd to update and create real estates, realtors etc.'

    def add_arguments(self, parser):
        parser.add_argument(
            '--all',
            action='store_false',
            dest='only_modified',
            default=True,
            help='Synchronize all real estates, not just modified ones',
        )

    def handle(self, *args, **options):
        if len(args) > 0:
            self.stdout.write(
                'This command takes no arguments. {} arguments ignored.'.format(len(args))
            )

        self.stdout.write('Starting synchronization...')
        Realtor.objects.synchronize()
        RealEstate.objects.synchronize(only_modified=options['only_modified'])
        self.stdout.write('Done.')
