import django
from django.utils import numberformat


def slugify(value, max_length=50):
    """
    Slugifies using django's slugify, but applies an optional limit.
    """
    slug = django.utils.text.slugify(value)
    if max_length > 0:
        slug = slug[:max_length]

    return slug


def currency_format(value):
    return numberformat.format(value, decimal_sep=',', grouping=3, thousand_sep=' ',
                               force_grouping=True)


def ensure_list(possible_list):
    """
    xmltodict only creates a list if there's more than one item. This method makes the
    result from xmltodict safe to loop over.
    """
    return possible_list if isinstance(possible_list, list) else [possible_list]
