from django.test import TestCase

from fasad.managers import FasAdBidManager
from fasad.models import Bid
from fasad import factories


class BidManagerTest(TestCase):

    @classmethod
    def setUpTestData(cls):
        cls.manager = FasAdBidManager()
        cls.manager.model = Bid
        cls.real_estate = factories.RealEstate()

        cls.bids_zero = {"Bids": {}}

        cls.bids_single = {"Bids": {"Bid": [{
               "@amount": "100",
               "@bidder": "Budgivare 1",
        }]}}

        cls.bids_multiple = {"Bids": {"Bid": [
            {
                "@amount": "100",
                "@bidder": "Budgivare 1",
            },
            {
                "@amount": "200",
                "@bidder": "Budgivare 2",
            },
        ]}}

    def test_update_or_create_from_json_saves_details(self):
        bid_json = self.bids_single['Bids']['Bid'][0]

        self.manager.update_or_create_from_json(self.real_estate, self.bids_single)

        bid = self.manager.first()

        self.assertEqual(bid.amount, 100)
        self.assertEqual(bid.bidder, 'Budgivare 1')

    def test_update_or_create_from_json_saves_multiple_bids(self):
        self.manager.update_or_create_from_json(self.real_estate, self.bids_multiple)

        self.assertEqual(self.manager.count(), 2)

    def test_update_or_create_from_json_saves_a_single_bid(self):
        self.manager.update_or_create_from_json(self.real_estate, self.bids_single)

        self.assertEqual(self.manager.count(), 1)

    def test_update_or_create_from_json_handles_zero_bids(self):
        self.manager.update_or_create_from_json(self.real_estate, self.bids_zero)

        self.assertFalse(self.manager.exists())

    def test_update_or_create_from_json_deletes_old_bids(self):
        old_bid = factories.Bid(real_estate=self.real_estate)

        self.assertTrue(self.manager.exists())

        self.manager.update_or_create_from_json(self.real_estate, self.bids_zero)

        self.assertFalse(self.manager.exists())
