from django.test import TestCase

from fasad.forms import RealEstateForm
from fasad.models import RealEstate


class RealEstateFormTest(TestCase):

    def test_clean_price_null(self):
        form = RealEstateForm({'price': None})
        form.is_valid()
        self.assertEqual(form.clean_price(), 0)

    def test_clean_price_empty_string(self):
        form = RealEstateForm({'price': ''})
        form.is_valid()
        self.assertEqual(form.clean_price(), 0)

    def test_clean_price_negative_value(self):
        form = RealEstateForm({'price': '-10'})
        form.is_valid()
        self.assertEqual(form.clean_price(), -10)

    def test_clean_price_positive_value(self):
        form = RealEstateForm({'price': '10'})
        form.is_valid()
        self.assertEqual(form.clean_price(), 10)

    def test_clean_min_bedrooms_null(self):
        form = RealEstateForm({'min_bedrooms': None})
        form.is_valid()
        self.assertEqual(form.clean_min_bedrooms(), None)

    def test_clean_min_bedrooms_empty_string(self):
        form = RealEstateForm({'min_bedrooms': ''})
        form.is_valid()
        self.assertEqual(form.clean_min_bedrooms(), None)

    def test_clean_max_bedrooms_null(self):
        form = RealEstateForm({'max_bedrooms': None})
        form.is_valid()
        self.assertEqual(form.clean_max_bedrooms(), None)

    def test_clean_max_bedrooms_empty_string(self):
        form = RealEstateForm({'max_bedrooms': ''})
        form.is_valid()
        self.assertEqual(form.clean_max_bedrooms(), None)
