import unittest

from fasad.utils import slugify


class UtilsTest(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        cls.value = "Foo Bar"
        cls.slug = "foo-bar"

    def test_slugify_zero_max_length(self):
        """
        Should treat zero max_length as unlimited.
        """
        self.assertEqual(slugify(self.value, max_length=0), self.slug)

    def test_slugify_with_negative_max_length(self):
        """
        Should treat negative max_length as unlimited.
        """
        self.assertEqual(slugify(self.value, max_length=-1), self.slug)

    def test_slugify_with_positive_max_length(self):
        """
        Should cut the string to the given max_length.
        """
        self.assertEqual(slugify(self.value, max_length=5), self.slug[:5])

    def test_slugify_with_higher_max_length_than_value_length(self):
        """
        Should not cut the value if it's shorter than max_length.
        """
        self.assertEqual(slugify(self.value, max_length=100), self.slug)
